.. _todo:

Todo
====

Things that still have to be build in. If you have any *must haves*, please
e-mail me at petar[ed]wunki.org.

SSL
---

All account sensitive information should be done through SSL. Of course, taking
into account that some people don't have a certificate, thus making this
optional through a setting.

API
---

An API would come in handy when you don't want to redirect after every post. It
would be nice if you just got a message "saved" when you change your account
settings. I'm seeing this as a new application inside userena, with it's own
``URLconf``.
